from django import forms
from .models import User
from datetime import date
from django.core.exceptions import ValidationError

class UserForm(forms.ModelForm):
    class Meta:
        model = User
        fields = [
            'nama', 
            'password', 
            'tanggal_lahir', 
            'nomor_hp', 
            'email', 
            'url_blog', 
            'deskripsi_diri', 
            'no_sim', 
            'no_plat'
        ]
        
        labels = {
            'nama': 'Nama',
            'password': 'Password',
            'tanggal_lahir': 'Tanggal Lahir',
            'nomor_hp': 'Nomor HP',
            'email': 'Email',
            'url_blog': 'URL Blog',
            'deskripsi_diri': 'Deskripsi Diri',
            'no_sim': 'No SIM',
            'no_plat': 'No Plat Kendaraan Bermotor'
        }
        
        widgets = {
            #'password': forms.PasswordInput(),  
            'tanggal_lahir': forms.DateInput(attrs={'type': 'date'}),  
        }
    
    def clean_tanggal_lahir(self):
        tanggal_lahir = self.cleaned_data.get('tanggal_lahir')
        if tanggal_lahir:
            today = date.today()
            age = today.year - tanggal_lahir.year - (
                (today.month, today.day) < (tanggal_lahir.month, tanggal_lahir.day)
            )
            if age < 12:
                raise ValidationError('Usia minimal adalah 12 tahun')
        return tanggal_lahir

    def clean_nomor_hp(self):
        nomor_hp = self.cleaned_data.get('nomor_hp', '')
        sanitized_nomor_hp = nomor_hp.replace('+', '').replace('-', '').replace(' ', '')

        if not sanitized_nomor_hp.isdigit():
            raise ValidationError("Nomor HP harus berupa angka")
        
        if len(sanitized_nomor_hp) < 8 or len(sanitized_nomor_hp) > 15:
            raise ValidationError("Nomor HP harus memiliki panjang antara 8 hingga 15 karakter")

        return sanitized_nomor_hp