from django.db import models
from django.contrib.auth.models import AbstractUser
from django.core.validators import RegexValidator, MinLengthValidator, MaxLengthValidator

# Create your models here.
class User(AbstractUser):
    groups = models.ManyToManyField('auth.Group', blank=True, related_name='form_regex_user_set')
    user_permissions = models.ManyToManyField('auth.Permission', blank=True, related_name='form_regex_user_set')
    
    nama = models.CharField(max_length = 255,
                            validators = [
                                RegexValidator(
                                    r'^[a-zA-Z0-9._-]+$',
                                    message = "Nama hanya dapat diisi oleh huruf, angka, dan karakter ., _, dan -"
                                )
                            ],
                            blank = False,
                            null = False)

    password = models.CharField(max_length = 255,
                                validators = [
                                    RegexValidator(
                                        r'^(?=.*?[A-Za-z])(?=.*?[0-9])(?=.*?[#?!@$%^&*-]).{8,}$',
                                        message = "Password harus diisi oleh kombinasi huruf, angka, dan karakter spesial dengan panjang minimal 8"
                                    )
                                ],
                                blank = False,
                                null = False)
    
    tanggal_lahir = models.DateField(blank = False, null = False)
    
    nomor_hp = models.CharField(max_length = 15,
                                validators = [
                                    MinLengthValidator(
                                        8,
                                        message = "Nomor HP memiliki panjang minimal 8"
                                    ),
                                    RegexValidator(
                                        r'^\d+$',
                                        message = "Nomor HP harus berupa angka, tanpa karakter + atau -"
                                    )
                                ],
                                blank = False,
                                null = False)
    
    email = models.CharField(max_length = 255,
                             validators = [
                                 RegexValidator(
                                     r'^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$',
                                     message = "Alamat email tidak valid!"
                                 )
                             ],
                             blank = False,
                             null = False,
                             unique = True)
    
    url_blog = models.CharField(max_length = 255,
                               validators = [
                                   RegexValidator(
                                       r'^(https?://)[\w.-]+(?:\.[\w\.-]+)+[/#?]?.*$',
                                       message = "URL Blog tidak valid!"
                                   )
                               ],
                               blank = False,
                               null = False)
    
    deskripsi_diri = models.TextField(
        validators = [
            MinLengthValidator(5, message = "Deskripsi diri minimal 5 karakter"),
            MaxLengthValidator(1000, message = "Deskripsi diri maksimal 1000 karakter")
        ],
        blank = False,
        null = False
    )
    
    no_sim = models.CharField(max_length = 16,
                              validators = [
                                    RegexValidator(
                                        r'^\d{16}$',
                                        message = 'Nomor SIM harus terdiri dari 16 angka'
                                    )
                              ],
                              blank = False,
                              null = False)

    no_plat = models.CharField(max_length = 9,
                               validators = [
                                   RegexValidator(
                                       r'^[A-Za-z]{1,2}\d{1,4}[A-Za-z]{0,3}$',
                                       message = "Nomor Plat harus terdiri dari 1-2 huruf di awal, 1-4 angka di tengah, dan 0-3 huruf di akhir"   
                                   )
                               ],
                               blank = False,
                               null = False)